Package: markmyassignment
Type: Package
Title: Automatic Marking of R Assignments
Version: 0.8.9
Authors@R: c(person(given = "Mans",
                      family = "Magnusson",
                      role = c("aut", "cre"),
                      email = "mons.magnusson@gmail.com"),
               person(given = "Oscar",
                      family = "Pettersson",
                      role = "aut"))
Maintainer: Mans Magnusson <mons.magnusson@gmail.com>
Description: Automatic marking of R assignments for students and teachers based
    on 'testthat' test suites.
License: BSD_2_clause + file LICENSE
Encoding: UTF-8
Depends: R (>= 3.6.0)
Imports: methods, yaml, testthat (>= 2.0.0), httr (>= 1.0.0), checkmate
        (>= 1.0.0), codetools, rlang
RoxygenNote: 7.3.3
Suggests: covr, httptest, knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-11-22 16:45:57 UTC; manma760
Author: Mans Magnusson [aut, cre],
  Oscar Pettersson [aut]
Repository: CRAN
Date/Publication: 2025-11-22 17:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 13:53:21 UTC; unix
