# Generated by roxygen2: do not edit by hand

export(expect_attached_package)
export(expect_function_arguments)
export(expect_function_code)
export(expect_function_self_contained)
export(expect_no_attached_forbidden_package)
export(expect_no_forbidden_function_code)
export(expect_package)
export(expect_self_contained)
export(is_assignment_set)
export(mark_my_assignment)
export(mark_my_dir)
export(mark_my_file)
export(remove_assignment)
export(set_assignment)
export(show_assignment)
export(show_tasks)
