## My lab report ###
myame <- "Foo Bar"

# Create a vector with the values pi and e
task1 <- c(pi+1, exp(1))  

# Create a function that return the sum of the first and last element.
task2 <- function(vector){
  pi
}

# mark_my_assignment()
