## My lab report ##
my_name <- "Foo Bar"
mark_my_assignment()

# Create a vector with the values pi and e
task1 <- c(pi, exp(1))  

# set_assignment()

# Create a function that return the sum of the first and last element.
task2 <- function(vector){
  install.packages("error")
  vector[1] + vector[length(vector)]
}

mark_my_assignment()


task3 <- function(vector){
  install.packages("error")
  vector[1] + vector[length(vector)]
  install.packages("2")
}


task4 <- function(vector){
  install.packages("error")
  vector[1] + vector[length(vector)]
  set_assignment()
}
