## My lab report ##
my_name <- "Foo Bar"

# Create a vector with the values pi and e
mydata <- my_data <- my.data <- my123data <- function() data.frame(x = 1:10, y = (1:10)^2)
task1 <- c(pi, exp(1))  

data("iris")

# Create a function that return the sum of the first and last element.
task2 <- function(vector){
  vector[1] + vector[length(vector)]
}

mydata();  my_data()

data("faithful")  ;   data("mtcars")
print("Hello");set_assignment("blabla", auth_token = NULL);data("ChickWeight");mark_my_assignment();
data("cars")
print(paste("Hello", "!"))
my.data()
my123data()

mark_my_assignment()
